@@ -1,13 +1,12 @@
 """Small URL manipulation helpers."""
 
-from typing import Dict
-from urllib.parse import urlencode, urlparse, parse_qs, urlunparse
-
+from typing import Dict, Any
+from urllib.parse import parse_qs, urlencode, urlparse, urlunparse
 
 __all__ = ("add_query_param",)
 
 
-def add_query_param(url: str, params: Dict[str, str]) -> str:
+def add_query_param(url: str, params: Dict[str, Any]) -> str:
     """Return ``url`` with additional query string parameters."""
 
     url_parts = urlparse(url)
