@@ -9,7 +9,23 @@ class DatabaseConfig:
     """Simple builder for SQLAlchemy connection settings."""
 
     def __init__(self) -> None:
-        self._config_data: dict[str, Any] = {}
+        self._config_data: dict[str, Any] = {
+            "db_backend": "postgresql",
+            "db_driver_async": "asyncpg",
+            "connect_args": None,
+        }
+
+    def set_db_backend(self, db_backend: str) -> "DatabaseConfig":
+        self._config_data["db_backend"] = db_backend
+        return self
+
+    def set_db_driver_async(self, db_driver_async: str) -> "DatabaseConfig":
+        self._config_data["db_driver_async"] = db_driver_async
+        return self
+
+    def set_connect_args(self, connect_args: dict) -> "DatabaseConfig":
+        self._config_data["connect_args"] = connect_args
+        return self
 
     def set_db_url(self, db_url: str) -> "DatabaseConfig":
         """Set full database URL for both read and write operations."""
