@@ -7,7 +7,7 @@ and health checks for both read and write connections.
 from __future__ import annotations
 
 from contextlib import asynccontextmanager, contextmanager
-from typing import AsyncGenerator, Generator, Optional
+from typing import AsyncGenerator, Generator, Optional, Any
 
 from sqlalchemy import NullPool, create_engine, text
 from sqlalchemy.ext.asyncio import AsyncSession, async_sessionmaker, create_async_engine
@@ -31,6 +31,11 @@ class DatabaseInstance:
     """
 
     def __init__(self, config: DatabaseConfig) -> None:
+        self.db_backend = (config.get("db_backend") or "postgresql").lower()
+        self.db_driver_sync = config.get("db_driver_sync")
+        self.db_driver_async = config.get("db_driver_async")
+        self.db_ssl = config.get("db_ssl", False)
+        self.connect_args = config.get("connect_args", None)
         self.db_user = config.get("db_user")
         self.db_password = config.get("db_password")
         self.db_host_write = config.get("db_host")
@@ -114,11 +119,19 @@ class DatabaseInstance:
         # Declarative base for ORM models
         self.base = declarative_base(name="Base")
 
-    @staticmethod
-    def _build_async_url(db_url: str) -> str:
+    def _build_async_url(self, db_url: str) -> str:
+        db_url = (
+            db_url
+            .replace(
+                f"{self.db_backend}://",
+                f"{self.db_backend}+{self.db_driver_async}://",
+                1
+            )
+        )
         if "postgresql" in db_url:
-            return db_url.replace("postgresql://", "postgresql+asyncpg://", 1).replace(
-                "sslmode=require", "ssl=require", 1
+            return (
+                db_url
+                .replace("sslmode=require", "ssl=require", 1)
             )
         else:
             return db_url
@@ -128,18 +141,28 @@ class DatabaseInstance:
     ) -> str:
         if host is None:
             host = self.db_host_write
-        scheme = "postgresql+asyncpg" if async_mode else "postgresql"
+
+        scheme = f"{self.db_backend}+{self.db_driver_async}" if async_mode else self.db_backend
         url = f"{scheme}://{self.db_user}:{self.db_password}@{host}:{self.db_port}/{self.db_name}"
+
         if self.db_ssl:
-            url += "?ssl=require" if async_mode else "?sslmode=require"
+            if self.db_backend == "postgresql":
+                url += "?ssl=require" if async_mode else "?sslmode=require"
+            elif self.db_backend == "mysql":
+                url += "?ssl-mode=REQUIRED"
+
         return url
 
     def _initialize_db_settings(self) -> dict:
         """Build engine keyword arguments based on pooling configuration."""
-        db_settings = {"pool_pre_ping": True, "echo": False}
+        settings: dict[str, Any] = {
+            "pool_pre_ping": True,
+            "echo": False,
+            "connect_args": self.connect_args or {},
+        }
 
         if self.db_pool_size:
-            db_settings.update(
+            settings.update(
                 {
                     "pool_size": self.db_pool_size,
                     "pool_recycle": 300,
@@ -148,9 +171,13 @@ class DatabaseInstance:
                 }
             )
         else:
-            db_settings["poolclass"] = NullPool
+            settings["poolclass"] = NullPool
 
-        return db_settings
+        # SSL
+        if self.db_ssl and self.db_backend == "mysql":
+            settings["connect_args"] = {**settings.get("connect_args", {}), "ssl": True}
+
+        return settings
 
     def session_local(self):
         """Create a new synchronous write session."""
