@@ -1,19 +1,19 @@
 from enum import Enum
-from typing import Any
 from math import ceil
-from sqlalchemy import func, distinct as distinct_func
+from typing import Any
+
+from sqlalchemy import distinct as distinct_func
+from sqlalchemy import func, select
 from sqlalchemy.orm import Session
 
+from .search_utils.filter_values import get_filters_value
 from .search_utils.free_search import free_search
 from .search_utils.make_condition import make_condition
-from .search_utils.filter_values import get_filters_value
 from .search_utils.selected_filters import make_selected_filters
 
-
 __all__ = ("get_list",)
 
 
-
 def get_list(
     current_query: dict,
     db: Session,
@@ -22,11 +22,10 @@ def get_list(
     pre_conditions: list = None,
     filters: list = None,
     searchable_columns: list = None,
-    exact_search: bool = True,
+    exact_search: bool = False,
     search_tokenizer: bool = False,
-    search_similarity_threshold: float = 0.2,
+    search_similarity_threshold: float = 0.1,
     options: list = None,
-    distinct=None,
     primary_column: str = "id",
     sorting_null_at_the_end: bool = True,
     get_function_parameters: dict = None,
@@ -34,6 +33,7 @@ def get_list(
     return_selected_filters: bool = True,
     return_rows_data: bool = True,
     export_mode: bool = False,
+    unique: bool = True,
 ):
     if joins is None:
         joins = []
@@ -56,32 +56,28 @@ def get_list(
     page = current_query.get("page") or 1
     items_per_page = current_query.get("items_per_page") or 30
 
-    # Create Initial Model Query
-    main_query = db.query(model)
+    orm_primary_column = getattr(model, primary_column)
 
-    if distinct is True:
-        distinct_column = getattr(model, primary_column)
-        count_query = db.query(func.count(distinct_func(distinct_column)))
-    elif distinct:
-        distinct_column = distinct
-        count_query = db.query(func.count(distinct_func(distinct_column)))
+    # Create Initial Model Query
+    main_query = select(model)
+
+    if unique:
+        count_query = select(func.count(distinct_func(orm_primary_column))).select_from(
+            model
+        )
     else:
-        distinct_column = None
-        count_query = db.query(func.count(getattr(model, primary_column)))
+        count_query = select(func.count()).select_from(model)
 
     for join_item in joins:
         main_query = main_query.join(**join_item)
         count_query = count_query.join(**join_item)
 
-    main_query = main_query.filter(*pre_conditions)
-    count_query = count_query.filter(*pre_conditions)
+    main_query = main_query.where(*pre_conditions)
+    count_query = count_query.where(*pre_conditions)
 
     # Initialize rows and conditions
     conditions = []
-
-    names_conditions = {}
-    for filter_item in filters:
-        names_conditions[filter_item.get("name")] = []
+    names_conditions = {filter_item.get("name"): [] for filter_item in filters}
 
     for filter_item in filters:
         name = filter_item.get("name")
@@ -98,8 +94,8 @@ def get_list(
                     inner_name_values.append(target_condition)
 
     if conditions:
-        main_query = main_query.filter(*conditions)
-        count_query = count_query.filter(*conditions)
+        main_query = main_query.where(*conditions)
+        count_query = count_query.where(*conditions)
 
     if search_query := current_query.get("search"):
         search_conditions, search_sort = free_search(
@@ -109,19 +105,20 @@ def get_list(
             exact=exact_search,
             tokenize=search_tokenizer,
         )
-        main_query = main_query.filter(*search_conditions)
-        count_query = count_query.filter(*search_conditions)
+        main_query = main_query.where(*search_conditions)
+        count_query = count_query.where(*search_conditions)
     else:
         search_sort = None
 
-    if distinct_column is not None:
-        main_query = main_query.distinct(distinct_column)
+    if unique:
+        main_query = main_query.distinct(orm_primary_column)
+        main_query.order_by(orm_primary_column)
 
-    if options:
-        main_query = main_query.options(*options)
+    dedup_cte = main_query.cte("dedup_cte")
 
-    order_by_list = [] if distinct_column is None else [distinct_column]
+    sorting = (current_query.get("sorting") or [])
 
+    order_by_list = []
     if search_sort is not None:
         order_by_list.extend(search_sort)
     elif sorting := (current_query.get("sorting") or []):
@@ -135,33 +132,49 @@ def get_list(
             sort_by = sort_by.value if isinstance(sort_by, Enum) else sort_by
             order_by = order_by.value if isinstance(order_by, Enum) else order_by
 
-            sort_by_model = getattr(model, sort_by) if isinstance(sort_by, str) else sort_by
-            order_by_model = getattr(sort_by_model, order_by) if isinstance(order_by, str) else order_by
+            sort_by_model = (
+                getattr(model, sort_by) if isinstance(sort_by, str) else sort_by
+            )
+            order_by_model = (
+                getattr(sort_by_model, order_by)
+                if isinstance(order_by, str)
+                else order_by
+            )
 
             if sorting_null_at_the_end:
                 order_by_list.append(order_by_model().nulls_last())
             else:
                 order_by_list.append(order_by_model())
 
+    final_query = select(model).join(dedup_cte, orm_primary_column == dedup_cte.c.id)
+
+    if options:
+        final_query = final_query.options(*options)
+
     if order_by_list:
-        final_query = main_query.order_by(*order_by_list)
-    else:
-        final_query = main_query
+        final_query = final_query.order_by(*order_by_list)
 
     if items_per_page and page:
         final_query = final_query.limit(items_per_page).offset(
             (page - 1) * items_per_page
         )
 
+    count_query = count_query.order_by(None)
+
     if return_rows_data:
-        rows = list(map(lambda x: x.get(**get_function_parameters), final_query.all()))
+        rows = list(
+            map(
+                lambda x: x.get(**get_function_parameters),
+                db.execute(final_query).unique().scalars().all(),
+            )
+        )
     else:
         rows = None
 
     if export_mode and return_rows_data:
         return rows
     else:
-        count = count_query.first()[0]
+        count = db.execute(count_query).scalar_one()
         current_query["total_row"] = count
 
         # Calculate pagination-related information
@@ -180,16 +193,20 @@ def get_list(
             result["rows_data"] = rows
 
         if return_available_filters:
-            result['available_filters'] = get_filters_value(
-                db=db,
-                pre_conditions=pre_conditions,
-                joins=joins,
-                filters=filters,
-                names_conditions=names_conditions,
-            ) if filters is not None else []
+            result["available_filters"] = (
+                get_filters_value(
+                    db=db,
+                    pre_conditions=pre_conditions,
+                    joins=joins,
+                    filters=filters,
+                    names_conditions=names_conditions,
+                )
+                if filters is not None
+                else []
+            )
 
         if return_selected_filters:
-            result['selected_filters'] = make_selected_filters(
+            result["selected_filters"] = make_selected_filters(
                 current_query=current_query,
                 filters=filters,
             )
